API
==================================

aind_behavior_curriculum
--------------------------

.. toctree::
   :maxdepth: 1

   aind_behavior_curriculum/base
   aind_behavior_curriculum/curriculum
   aind_behavior_curriculum/task
   aind_behavior_curriculum/trainer
   aind_behavior_curriculum/curriculum_utils

